==> nest-infrastructure-middleware-redis-3.5.3.0-20251212.071510-6-sources.jar: com/digiwin/dap/nest/infrastructure/middleware/redis/adapter/spring/command/JaRedisTemplateLockCommand.java <==
package com.digiwin.dap.nest.infrastructure.middleware.redis.adapter.spring.command;

import com.digiwin.dap.nest.infrastructure.middleware.redis.DwRedis;
import com.digiwin.dap.nest.infrastructure.middleware.redis.JaRedisLockCommand;
import com.digiwin.dap.nest.infrastructure.middleware.redis.adapter.spring.JaRedisTemplateProcessor;
import com.digiwin.dap.nest.infrastructure.middleware.redis.meta.JaRedisConstants;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.script.DefaultRedisScript;

import java.util.Collections;

@SuppressWarnings({"unchecked", "rawtypes"})
public class JaRedisTemplateLockCommand implements JaRedisLockCommand {

    private static final DefaultRedisScript<Long> releaseScript = new DefaultRedisScript<>(JaRedisConstants.LuaReleaseScript, Long.class);

    private final RedisTemplate redisTemplate;

    public JaRedisTemplateLockCommand() {
        redisTemplate = JaRedisTemplateProcessor.getRedisTemplate();
    }


    /**
     * 上锁
     *
     * @param lockKey    需要获取的锁key
     * @param requestId  请求id
     * @param expireTime 过期时间 milliseconds
     * @return true:上锁成功, false:上锁失败
     */
    @Override
    public boolean lock(String lockKey, String requestId, long expireTime) {
        return DwRedis.setNx(lockKey, requestId, expireTime / 1000);
    }

    /**
     * 释放锁
     *
     * @param lockKey   释放的锁key
     * @param requestId 请求id
     * @return true:释放成功, false:释放失败
     */
    @Override
    public boolean unLock(String lockKey, String requestId) {
        return JaRedisConstants.LuaSuccess.equals(redisTemplate.execute(releaseScript, Collections.singletonList(lockKey), requestId));
    }
}

==> nest-infrastructure-middleware-redis-5.5.0.1000-20251217.112142-5-sources.jar: com/digiwin/dap/nest/infrastructure/middleware/redis/adapter/spring/command/JaRedisTemplateLockCommand.java <==
package com.digiwin.dap.nest.infrastructure.middleware.redis.adapter.spring.command;

import com.digiwin.dap.nest.infrastructure.middleware.redis.DwRedis;
import com.digiwin.dap.nest.infrastructure.middleware.redis.DwRedisLockCommand;
import com.digiwin.dap.nest.infrastructure.middleware.redis.adapter.spring.JaRedisTemplateProcessor;
import com.digiwin.dap.nest.infrastructure.middleware.redis.meta.JaRedisConstants;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.script.DefaultRedisScript;

import java.util.Collections;

@SuppressWarnings({"unchecked", "rawtypes"})
public class JaRedisTemplateLockCommand implements DwRedisLockCommand {

    private static final DefaultRedisScript<Long> releaseScript = new DefaultRedisScript<>(JaRedisConstants.LuaReleaseScript, Long.class);

    private final RedisTemplate redisTemplate;

    public JaRedisTemplateLockCommand() {
        redisTemplate = JaRedisTemplateProcessor.getRedisTemplate();
    }


    /**
     * 上锁
     *
     * @param lockKey    需要获取的锁key
     * @param requestId  请求id
     * @param expireTime 过期时间 milliseconds
     * @return true:上锁成功, false:上锁失败
     */
    @Override
    public boolean lock(String lockKey, String requestId, long expireTime) {
        return DwRedis.setNx(lockKey, requestId, expireTime / 1000);
    }

    /**
     * 释放锁
     *
     * @param lockKey   释放的锁key
     * @param requestId 请求id
     * @return true:释放成功, false:释放失败
     */
    @Override
    public boolean unLock(String lockKey, String requestId) {
        return JaRedisConstants.LuaSuccess.equals(redisTemplate.execute(releaseScript, Collections.singletonList(lockKey), requestId));
    }
}
